#undef PACKAGE
#undef VERSION

#undef HAVE_LIBSM
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY

#undef ENABLE_PROFILER

#undef GUPPI_MAJOR_VERSION
#undef GUPPI_MINOR_VERSION
#undef GUPPI_MICRO_VERSION
#undef GUPPI_FROM_CVS

#undef USING_OLD_FONT_API
#undef HAVE_GUILE
#undef USING_GUILE_1_3_0
#undef USING_GUILE_1_3_X
#undef USING_GUILE_1_4_X
#undef HAVE_HISTORY
#undef HAVE_READLINE
#undef WORKING_GUILE_READLINE
#undef READLINE_LIB
#undef HAVE_LIBSM
#undef HAVE_GUILE_GTK
#undef HAVE_GUILE_GNOME
#undef USING_BONOBO
#undef HAVE_PYTHON


#undef GNOME_XML_HEADER_VERSION_1
#undef GNOME_XML_HEADER_VERSION_2
